Page 104 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 104

Home

    Foreign Relations. This plan called for massive loans to
    Germany. Under this plan I. G. Farben received a loan of
    $30 million from the Rockefeller's National City Bank.

    It would not have been possible for the German war
    machine to have been rebuilt after World War I without

    help from financial circles in the United States. The
    Krupp munitions works was salvaged by a $10 million
    oan from companies in New York, as was the Farben
    controlled steel works with a $100 million loan.

    with I. G. Farben creating interlocking business interests
    around the world. Throughout World War II this was

    kept secret by a complicated network of companies set
    up for that purpose.
    American technology, engineering, and entire

    American technology, engineering, and entire
    companies went to Germany. Many of these companies
    made profits supplying war materials for both sides of
    the war. While American companies were making profits
    on the German side, I. G. Farben was making profits on

    and

    entire

    During the Nuremberg Trials it was learned that the
    business leaders of I. G. Farben had controlled the Nazi

    state. Farben operated such concentration camps as
    Auschwitz and Buchenwald. Although Farben was the
    backbone of the Nazi war machine, its influence was so

    great that its headquarters buildings in Frankfort,
    Germany were off limits to American bombardiers.
    These buildings survived the war unharmed.

    99

    Building Modern Babylon

    States after World War I and backed by the Council on

    In 1928 John D. Rockefeller, Sr. formed a partnership

    ‘technology,

    the American side.